@@ -114,8 +114,8 @@ $tpl->define(array("main" => "edit.html",
 
 $tpl->assign(array("LIST" =>htmlentities($list)));
 
-$handle = fopen("../conf/tunables.pl", "r");
-$tunables = fread($handle, filesize("../conf/tunables.pl"));
+$handle = fopen("$templatedir/../conf/tunables.pl", "r");
+$tunables = fread($handle, filesize("$templatedir/../conf/tunables.pl"));
 fclose($handle);
 
 eval($tunables);
