@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Morten K. Poulsen <morten at afdelingp.dk>
  *
- * $Id: mlmmj-bounce.c,v 1.41 2006/08/06 08:36:47 xi Exp $
+ * $Id: mlmmj-bounce.c,v 1.44 2008/10/31 14:20:51 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -55,7 +55,7 @@ char *fetchindexes(const char *bouncefile)
 	char *indexstr = NULL, *s, *start, *line, *cur, *colon, *next;
 	size_t len;
 	struct stat st;
-	
+
 	fd = open(bouncefile, O_RDONLY);
 	if(fd < 0) {
 		log_error(LOG_ARGS, "Could not open bounceindexfile %s",
@@ -68,13 +68,19 @@ char *fetchindexes(const char *bouncefile)
 					bouncefile);
 	}
 
+	if(st.st_size == 0) {
+		log_error(LOG_ARGS, "Bounceindexfile %s is size 0",
+					bouncefile);
+		return NULL;
+	}
+
 	start = mmap(0, st.st_size, PROT_READ, MAP_SHARED, fd, 0);
 	if(start == MAP_FAILED) {
 		log_error(LOG_ARGS, "Could not mmap bounceindexfile");
 		return NULL;
 	}
-	
-	
+
+
 	for(next = cur = start; next < start + st.st_size; next++) {
 		if(*next == '\n') {
 			len = next - cur;
@@ -86,13 +92,14 @@ char *fetchindexes(const char *bouncefile)
 	 		continue;
 
 		colon = strchr(line, ':');
+		MY_ASSERT(colon);
 		*colon = '\0';
 		s = indexstr;
 		indexstr = concatstr(4, s, "        ", line, "\n");
 		myfree(s);
 		myfree(line);
 	}
-		
+
 	munmap(start, st.st_size);
 	close(fd);
 
@@ -139,7 +146,7 @@ void do_probe(const char *listdir, const char *mlmmjsend, const char *addr)
 
 	maildata[1] = indexstr;
 	queuefilename = prepstdreply(listdir, "bounce-probe", "$listowner$",
-					myaddr, NULL, 1, maildata, NULL);
+					myaddr, NULL, 1, maildata, NULL, NULL);
 	MY_ASSERT(queuefilename);
 	myfree(indexstr);
 
@@ -200,7 +207,7 @@ char *dsnparseaddr(const char *mailname)
 					addr = mystrdup(emails.emaillist[0]);
 					for(i = 0; i < emails.emailcount; i++)
 						myfree(emails.emaillist[i]);
-					myfree(emails.emaillist);	
+					myfree(emails.emaillist);
 				} else {
 					addr = NULL;
 				}
@@ -210,7 +217,7 @@ char *dsnparseaddr(const char *mailname)
 		}
 		myfree(line);
 	}
-	
+
 	return NULL;
 }
 
@@ -314,6 +321,7 @@ int main(int argc, char **argv)
 			exit(EXIT_SUCCESS);
 
 		a = strrchr(address, '@');
+		MY_ASSERT(a);
 		*a = '=';
 	}
 
@@ -325,7 +333,7 @@ int main(int argc, char **argv)
 		i++;
 	}
 	address = lowcaseaddr;
-			
+
 	if(number != NULL && probe != 0) {
 		fprintf(stderr, "You can only specify one of -n or -p\n");
 		fprintf(stderr, "%s -h for help\n", argv[0]);
@@ -375,7 +383,7 @@ int main(int argc, char **argv)
 		myfree(a);
 		exit(EXIT_SUCCESS);
 	}
-	
+
 	/* save the filename with '=' before replacing it with '@' */
 	bfilename = concatstr(3, listdir, "/bounce/", address);
 
@@ -435,7 +443,7 @@ int main(int argc, char **argv)
 		rename(mailname, savename);
 		myfree(savename);
 	}
-		
+
 	myfree(bfilename);
 	if(dsnbounce && address)
 		myfree(address);
