@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-maintd.c,v 1.59 2006/11/14 13:15:54 xi Exp $
+ * $Id: mlmmj-maintd.c,v 1.61 2008/10/31 14:20:51 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -42,6 +42,7 @@
 #include "wrappers.h"
 #include "memory.h"
 #include "ctrlvalue.h"
+#include "statctrl.h"
 #include "send_digest.h"
 #include "mylocking.h"
 #include "log_oper.h"
@@ -244,6 +245,7 @@ int resend_queue(const char *listdir, const char *mlmmjsend)
 
 		if(strchr(dp->d_name, '.')) {
 			ch = strrchr(mailname, '.');
+			MY_ASSERT(ch);
 			*ch = '\0';
 			if(stat(mailname, &st) < 0) {
 				if(errno == ENOENT) {
@@ -769,6 +771,10 @@ int run_digests(const char *listdir, const char *mlmmjsend)
 	long digestmaxmails, lastindex, index, lastissue;
 	int fd, indexfd, lock;
 	size_t lenbuf, lenstr;
+
+	if (statctrl(listdir, "noarchive")) {
+		return 0;
+	}
 	
 	digestintervalstr = ctrlvalue(listdir, "digestinterval");
 	if (digestintervalstr) {
