@@ -1,6 +1,6 @@
 /* Copyright (C) 2003, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-process.c,v 1.83 2007/05/09 16:59:23 mortenp Exp $
+ * $Id: mlmmj-process.c,v 1.85 2008/10/31 12:29:44 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -76,8 +76,7 @@ void newmoderated(const char *listdir, const char *mailfilename,
 	char *buf, *replyto, *listaddr = getlistaddr(listdir), *listdelim;
 	char *queuefilename = NULL, *moderatorsfilename;
 	char *mailbasename = mybasename(mailfilename), *tmp, *to;
-	int queuefd, moderatorsfd, mailfd;
-	size_t count = 0;
+	int moderatorsfd;
 	char *maildata[4] = { "moderateaddr", NULL, "moderators", NULL };
 #if 0
 	printf("mailfilename = [%s], mailbasename = [%s]\n", mailfilename,
@@ -86,11 +85,6 @@ void newmoderated(const char *listdir, const char *mailfilename,
 	listfqdn = genlistfqdn(listaddr);
 	listname = genlistname(listaddr);
 
-	if((mailfd = open(mailfilename, O_RDONLY)) < 0) {
-		log_error(LOG_ARGS, "Could not open '%s'", mailfilename);
-		exit(EXIT_FAILURE);
-	}
-
 	moderatorsfilename = concatstr(2, listdir, "/control/moderators");
 	if((moderatorsfd = open(moderatorsfilename, O_RDONLY)) < 0) {
 		log_error(LOG_ARGS, "Could not open '%s'", moderatorsfilename);
@@ -123,25 +117,7 @@ void newmoderated(const char *listdir, const char *mailfilename,
 	myfree(listfqdn);
 
 	queuefilename = prepstdreply(listdir, "moderation", "$listowner$",
-				     to, replyto, 2, maildata, NULL);
-
-	if((queuefd = open(queuefilename, O_WRONLY|O_APPEND)) < 0) {
-		log_error(LOG_ARGS, "Could not open '%s'", queuefilename);
-		myfree(queuefilename);
-		exit(EXIT_FAILURE);
-	}
-	
-	while(count < 100 && (buf = mygetline(mailfd))) {
-		tmp = concatstr(2, " ", buf);
-		myfree(buf);
-		if(writen(queuefd, tmp, strlen(tmp)) < 0)
-			log_error(LOG_ARGS, "Could not write line for "
-					    "moderatemail");
-		myfree(tmp);
-		count++;
-	}
-	close(queuefd);
-	close(mailfd);
+				     to, replyto, 2, maildata, NULL, mailfilename);
 
 	execlp(mlmmjsend, mlmmjsend,
 				"-l", "2",
@@ -258,7 +234,7 @@ static enum action do_access(struct strlist *rule_strs, struct strlist *hdrs,
 		}
 
 		regfree(&regexp);
-		
+
 		if (match != not) {
 			if (match) {
 				hdr = mystrdup(hdrs->strs[j]);
@@ -378,7 +354,7 @@ int main(int argc, char **argv)
 	mlmmjunsub = concatstr(2, bindir, "/mlmmj-unsub");
 	mlmmjbounce = concatstr(2, bindir, "/mlmmj-bounce");
 	myfree(bindir);
-	
+
 	while ((opt = getopt(argc, argv, "hVPm:L:")) != -1) {
 		switch(opt) {
 		case 'L':
@@ -434,7 +410,7 @@ int main(int argc, char **argv)
 						S_IRUSR|S_IWUSR);
 
         } while ((donemailfd < 0) && (errno == EEXIST));
-	
+
 	if(donemailfd < 0) {
 		log_error(LOG_ARGS, "could not create %s", donemailname);
 		myfree(donemailname);
@@ -455,7 +431,7 @@ int main(int argc, char **argv)
 	headerfilename = concatstr(2, listdir, "/control/customheaders");
 	hdrfd = open(headerfilename, O_RDONLY);
 	myfree(headerfilename);
-	
+
     /* footfd is checked in do_all_the_voodo_here(), see above */
 	footerfilename = concatstr(2, listdir, "/control/footer");
 	footfd = open(footerfilename, O_RDONLY);
@@ -473,9 +449,9 @@ int main(int argc, char **argv)
 	delheaders->strs[delheaders->count++] = mystrdup("From ");
 	delheaders->strs[delheaders->count++] = mystrdup("Return-Path:");
 	delheaders->strs[delheaders->count] = NULL;
-	
-	subjectprefix = ctrlvalue(listdir, "prefix");	
-	
+
+	subjectprefix = ctrlvalue(listdir, "prefix");
+
 	if(do_all_the_voodo_here(rawmailfd, donemailfd, hdrfd, footfd,
 				(const char**)delheaders->strs, readhdrs,
 				&allheaders, subjectprefix) < 0) {
@@ -623,7 +599,7 @@ int main(int argc, char **argv)
 
 	listaddr = getlistaddr(listdir);
 	alternates = ctrlvalues(listdir, "listaddress");
-	
+
 	/* checking incoming mail's size */
 	maxmailsizestr = ctrlvalue(listdir, "maxmailsize");
 	if(maxmailsizestr) {
@@ -657,7 +633,7 @@ int main(int argc, char **argv)
 			queuefilename = prepstdreply(listdir,
 					"maxmailsize", "$listowner$",
 					fromemails.emaillist[0],
-					NULL, 2, maildata, NULL);
+					NULL, 2, maildata, NULL, donemailname);
 			MY_ASSERT(queuefilename)
 			myfree(listdelim);
 			myfree(listname);
@@ -672,14 +648,14 @@ int main(int argc, char **argv)
 					"-T", fromemails.emaillist[0],
 					"-F", fromaddr,
 					"-m", queuefilename, (char *)NULL);
-		
+
 			log_error(LOG_ARGS, "execlp() of '%s' failed", mlmmjsend);
 			exit(EXIT_FAILURE);
 		}
 	}
 
 	/* discard malformed mail with invalid From: */
-	if(fromemails.emailcount != 1) { 
+	if(fromemails.emailcount != 1) {
 		for(i = 0; i < fromemails.emailcount; i++)
 			printf("fromemails.emaillist[%d] = %s\n",
 					i, fromemails.emaillist[i]);
@@ -723,6 +699,8 @@ int main(int argc, char **argv)
 	addrtocc = !(statctrl(listdir, "tocc"));
 	if(addrtocc) {
 		for(i = 0; i < toemails.emailcount; i++) {
+			log_error(LOG_ARGS, "Found To: %s",
+				toemails.emaillist[i]);
 			for(j = 0; j < alternates->count; j++) {
 				chomp(alternates->strs[j]);
 				if(strcasecmp(alternates->strs[j],
@@ -731,6 +709,8 @@ int main(int argc, char **argv)
 			}
 		}
 		for(i = 0; i < ccemails.emailcount; i++) {
+			log_error(LOG_ARGS, "Found Cc: %s",
+				ccemails.emaillist[i]);
 			for(j = 0; j < alternates->count; j++) {
 				chomp(alternates->strs[j]);
 				if(strcasecmp(alternates->strs[j],
@@ -744,7 +724,7 @@ int main(int argc, char **argv)
 		myfree(alternates->strs[i]);
 
 	notoccdenymails = statctrl(listdir, "notoccdenymails");
-	
+
 	if(addrtocc && !intocc) {
 		/* Don't send a mail about denial to the list, but silently
 		 * discard and exit. Also don't in case of it being turned off
@@ -768,7 +748,7 @@ int main(int argc, char **argv)
 				     listfqdn);
 		queuefilename = prepstdreply(listdir, "notintocc",
 					"$listowner$", fromemails.emaillist[0],
-					     NULL, 0, NULL, NULL);
+					     NULL, 0, NULL, NULL, donemailname);
 		MY_ASSERT(queuefilename)
 		myfree(listdelim);
 		myfree(listname);
@@ -807,7 +787,7 @@ int main(int argc, char **argv)
 				moderated = 1;
 				goto startaccess;
 			}
-			
+
 			nosubonlydenymails = statctrl(listdir,
 					"nosubonlydenymails");
 
@@ -829,7 +809,7 @@ int main(int argc, char **argv)
 					"bounces-help@", listfqdn);
 			queuefilename = prepstdreply(listdir, "subonlypost",
 					"$listowner$", fromemails.emaillist[0],
-						     NULL, 1, maildata, NULL);
+						     NULL, 1, maildata, NULL, donemailname);
 			MY_ASSERT(queuefilename)
 			myfree(listaddr);
 			myfree(listdelim);
@@ -880,7 +860,7 @@ startaccess:
 			queuefilename = prepstdreply(listdir, "access",
 							"$listowner$",
 							fromemails.emaillist[0],
-						     NULL, 0, NULL, NULL);
+						     NULL, 0, NULL, NULL, donemailname);
 			MY_ASSERT(queuefilename)
 			myfree(listaddr);
 			myfree(listdelim);
@@ -917,7 +897,7 @@ startaccess:
                 	exit(EXIT_SUCCESS);
 		}
 	}
-	
+
 	if(!moderated)
 		moderated = statctrl(listdir, "moderated");
 	if(moderated) {
@@ -943,7 +923,7 @@ startaccess:
 		/* XXX: toemails and ccemails etc. have to be myfree() */
 		exit(EXIT_SUCCESS);
 	}
-	
+
 	execlp(mlmmjsend, mlmmjsend,
 				"-L", listdir,
 				"-m", donemailname, (char *)NULL);
